@@ -281,15 +281,16 @@ setMethod("crunch", "EnsDb", function(obj, which,
         }
         if(length(which) > 1)
             stop("'which' has to be a single GRanges object.")
-        if(!is.na(genome(which))){
-            if(unname(genome(which)) != unique(unname(genome(obj))))
+        if(!all(is.na(genome(which)))){
+            if(!all(genome(which) %in% genome(obj)))
                 stop("Genome versions do not fit! Argument 'which' has ",
-                     unname(genome(which)), " argument 'obj' ",
-                     unname(unique(genome(which))), "!")
+                     paste(genome(which), collapse=","), " argument 'obj' ",
+                     paste(genome(obj), collapse=","), "!")
         }
         ## Check if we've got the seqnames.
-        if(!(seqlevels(which) %in% seqlevels(obj)))
-            stop(seqlevels(which), " does not match any seqlevel in argument 'obj'!")
+        if(!all(seqnames(which) %in% seqlevels(obj)))
+            stop(paste(seqlevels(which), collapse=", "),
+                 " do(es) not match any seqlevel in argument 'obj'!")
         exFilter <- GRangesFilter(which, type = "any")
     } else exFilter <- which
     ## Check input argument 'columns':
@@ -361,7 +362,7 @@ setMethod("crunch", "EnsDb", function(obj, which,
             codingReg <- split(codingReg, codingReg$tx_id)
             regUTRs <- unlist(setdiff(codingTx, codingReg))
             mcols(regUTRs) <- mDf[match(names(regUTRs), mDf$tx_id), ]
-            regUTRs$type <- "utr"
+            regUTRs$type <- rep("utr", length(regUTRs))
             message("OK\nDefining CDS...", appendLF=FALSE)
             ## 4) Define CDS
             regCDSs <- unlist(intersect(codingTx, codingReg))
